@@ -10,10 +10,11 @@ Public interface for student training:
 
 import logging
 
-from django.db import DatabaseError
-from django.utils.translation import ugettext as _
-
 from submissions import api as sub_api
+
+from django.db import DatabaseError
+from django.utils.translation import gettext as _
+
 from openassessment.assessment.errors import StudentTrainingInternalError, StudentTrainingRequestError
 from openassessment.assessment.models import InvalidRubricSelection, StudentTrainingWorkflow
 from openassessment.assessment.serializers import (InvalidRubric, InvalidTrainingExample, deserialize_training_examples,
